==> cloudbees-folder-5.2.1-sources.jar: com/cloudbees/hudson/plugins/folder/computed/Messages.java <==
// CHECKSTYLE:OFF

package com.cloudbees.hudson.plugins.folder.computed;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code
     * ThrottleComputationQueueTaskDispatcher.MaxConcurrentIndexing}: {@code
     * At maximum indexing capacity}.
     * 
     * @return
     *     {@code At maximum indexing capacity}
     */
    public static String ThrottleComputationQueueTaskDispatcher_MaxConcurrentIndexing() {
        return holder.format("ThrottleComputationQueueTaskDispatcher.MaxConcurrentIndexing");
    }

    /**
     * Key {@code
     * ThrottleComputationQueueTaskDispatcher.MaxConcurrentIndexing}: {@code
     * At maximum indexing capacity}.
     * 
     * @return
     *     {@code At maximum indexing capacity}
     */
    public static Localizable _ThrottleComputationQueueTaskDispatcher_MaxConcurrentIndexing() {
        return new Localizable(holder, "ThrottleComputationQueueTaskDispatcher.MaxConcurrentIndexing");
    }

    /**
     * Key {@code ComputedFolder.already_computing}: {@code Already
     * computing}.
     * 
     * @return
     *     {@code Already computing}
     */
    public static String ComputedFolder_already_computing() {
        return holder.format("ComputedFolder.already_computing");
    }

    /**
     * Key {@code ComputedFolder.already_computing}: {@code Already
     * computing}.
     * 
     * @return
     *     {@code Already computing}
     */
    public static Localizable _ComputedFolder_already_computing() {
        return new Localizable(holder, "ComputedFolder.already_computing");
    }

}

==> cloudbees-folder-5.14-sources.jar: com/cloudbees/hudson/plugins/folder/computed/Messages.java <==
// CHECKSTYLE:OFF

package com.cloudbees.hudson.plugins.folder.computed;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code
     * ThrottleComputationQueueTaskDispatcher.MaxConcurrentIndexing}: {@code
     * At maximum indexing capacity}.
     * 
     * @return
     *     {@code At maximum indexing capacity}
     */
    public static String ThrottleComputationQueueTaskDispatcher_MaxConcurrentIndexing() {
        return holder.format("ThrottleComputationQueueTaskDispatcher.MaxConcurrentIndexing");
    }

    /**
     * Key {@code
     * ThrottleComputationQueueTaskDispatcher.MaxConcurrentIndexing}: {@code
     * At maximum indexing capacity}.
     * 
     * @return
     *     {@code At maximum indexing capacity}
     */
    public static Localizable _ThrottleComputationQueueTaskDispatcher_MaxConcurrentIndexing() {
        return new Localizable(holder, "ThrottleComputationQueueTaskDispatcher.MaxConcurrentIndexing");
    }

    /**
     * Key {@code FolderComputation.DisplayName}: {@code Folder Computation}.
     * 
     * @return
     *     {@code Folder Computation}
     */
    public static String FolderComputation_DisplayName() {
        return holder.format("FolderComputation.DisplayName");
    }

    /**
     * Key {@code FolderComputation.DisplayName}: {@code Folder Computation}.
     * 
     * @return
     *     {@code Folder Computation}
     */
    public static Localizable _FolderComputation_DisplayName() {
        return new Localizable(holder, "FolderComputation.DisplayName");
    }

    /**
     * Key {@code ComputedFolder.already_computing}: {@code Already
     * computing}.
     * 
     * @return
     *     {@code Already computing}
     */
    public static String ComputedFolder_already_computing() {
        return holder.format("ComputedFolder.already_computing");
    }

    /**
     * Key {@code ComputedFolder.already_computing}: {@code Already
     * computing}.
     * 
     * @return
     *     {@code Already computing}
     */
    public static Localizable _ComputedFolder_already_computing() {
        return new Localizable(holder, "ComputedFolder.already_computing");
    }

}
